pub struct AllowlistAdd {
pub authority: Pubkey,
pub config: Pubkey,
pub role_registry: Pubkey,
pub allowlist_entry: Pubkey,
pub address_to_allowlist: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for AllowlistAdd.
Fields
config: Pubkeyrole_registry: Pubkeyallowlist_entry: Pubkeyaddress_to_allowlist: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AllowlistAddwhere
Pubkey: BorshSerialize,
impl BorshSerialize for AllowlistAddwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AllowlistAdd
impl ToAccountMetas for AllowlistAdd
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AllowlistAdd
impl RefUnwindSafe for AllowlistAdd
impl Send for AllowlistAdd
impl Sync for AllowlistAdd
impl Unpin for AllowlistAdd
impl UnsafeUnpin for AllowlistAdd
impl UnwindSafe for AllowlistAdd