pub struct BlacklistAdd {
pub authority: Pubkey,
pub config: Pubkey,
pub role_registry: Pubkey,
pub blacklist_entry: Pubkey,
pub address_to_blacklist: Pubkey,
pub mint: Pubkey,
pub target_token_account: Pubkey,
pub token_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for BlacklistAdd.
Fields
config: Pubkeyrole_registry: Pubkeyblacklist_entry: Pubkeyaddress_to_blacklist: Pubkeymint: Pubkeytarget_token_account: PubkeyThe target’s token account to freeze
token_program: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for BlacklistAddwhere
Pubkey: BorshSerialize,
impl BorshSerialize for BlacklistAddwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for BlacklistAdd
impl ToAccountMetas for BlacklistAdd
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for BlacklistAdd
impl RefUnwindSafe for BlacklistAdd
impl Send for BlacklistAdd
impl Sync for BlacklistAdd
impl Unpin for BlacklistAdd
impl UnsafeUnpin for BlacklistAdd
impl UnwindSafe for BlacklistAdd