pub struct Seize {
pub authority: Pubkey,
pub config: Pubkey,
pub role_registry: Pubkey,
pub blacklist_entry: Pubkey,
pub mint: Pubkey,
pub from_token_account: Pubkey,
pub to_token_account: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for Seize.
Fields
config: Pubkeyrole_registry: Pubkeyblacklist_entry: PubkeyProves the target is blacklisted
mint: Pubkeyfrom_token_account: PubkeyThe token account to seize from (must be owned by the blacklisted address)
to_token_account: PubkeyThe destination token account (e.g., treasury)
token_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Seizewhere
Pubkey: BorshSerialize,
impl BorshSerialize for Seizewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for Seize
impl ToAccountMetas for Seize
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Seize
impl RefUnwindSafe for Seize
impl Send for Seize
impl Sync for Seize
impl Unpin for Seize
impl UnsafeUnpin for Seize
impl UnwindSafe for Seize