pub struct UpdateMetadata {
pub authority: Pubkey,
pub config: Pubkey,
pub role_registry: Pubkey,
}Expand description
Generated client accounts for UpdateMetadata.
Fields
config: Pubkeyrole_registry: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateMetadatawhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateMetadatawhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateMetadata
impl ToAccountMetas for UpdateMetadata
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateMetadata
impl RefUnwindSafe for UpdateMetadata
impl Send for UpdateMetadata
impl Sync for UpdateMetadata
impl Unpin for UpdateMetadata
impl UnsafeUnpin for UpdateMetadata
impl UnwindSafe for UpdateMetadata