pub struct UpdateMinter {
pub authority: Pubkey,
pub config: Pubkey,
pub role_registry: Pubkey,
pub minter_info: Pubkey,
pub minter_wallet: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for UpdateMinter.
Fields
config: Pubkeyrole_registry: Pubkeyminter_info: Pubkeyminter_wallet: Pubkeybeyond zero-address check. Minter is activated separately via is_active flag.
system_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateMinterwhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateMinterwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateMinter
impl ToAccountMetas for UpdateMinter
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateMinter
impl RefUnwindSafe for UpdateMinter
impl Send for UpdateMinter
impl Sync for UpdateMinter
impl Unpin for UpdateMinter
impl UnsafeUnpin for UpdateMinter
impl UnwindSafe for UpdateMinter