pub struct AccountThawed {
pub config: Pubkey,
pub authority: Pubkey,
pub target_account: Pubkey,
pub timestamp: i64,
}Fields
config: Pubkeytarget_account: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for AccountThawed
impl BorshDeserialize for AccountThawed
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AccountThawed
impl BorshSerialize for AccountThawed
Sourceimpl Discriminator for AccountThawed
impl Discriminator for AccountThawed
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more