pub struct AllowlistAdded {
pub config: Pubkey,
pub address: Pubkey,
pub added_by: Pubkey,
pub reason: String,
pub timestamp: i64,
}Fields
config: Pubkeyaddress: Pubkeyadded_by: Pubkeyreason: Stringtimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for AllowlistAdded
impl BorshDeserialize for AllowlistAdded
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AllowlistAdded
impl BorshSerialize for AllowlistAdded
Sourceimpl Discriminator for AllowlistAdded
impl Discriminator for AllowlistAdded
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more