pub struct AllowlistRemoved {
pub config: Pubkey,
pub address: Pubkey,
pub removed_by: Pubkey,
pub timestamp: i64,
}Fields
config: Pubkeyaddress: Pubkeyremoved_by: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for AllowlistRemoved
impl BorshDeserialize for AllowlistRemoved
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AllowlistRemoved
impl BorshSerialize for AllowlistRemoved
Sourceimpl Discriminator for AllowlistRemoved
impl Discriminator for AllowlistRemoved
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more