pub struct AuditLogRecorded {
pub config: Pubkey,
pub index: u64,
pub action: u8,
pub actor: Pubkey,
pub timestamp: i64,
}Fields
config: Pubkeyindex: u64action: u8actor: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for AuditLogRecorded
impl BorshDeserialize for AuditLogRecorded
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AuditLogRecorded
impl BorshSerialize for AuditLogRecorded
Sourceimpl Discriminator for AuditLogRecorded
impl Discriminator for AuditLogRecorded
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more