pub struct MinterUpdated {
pub config: Pubkey,
pub minter: Pubkey,
pub is_active: bool,
pub mint_quota: u64,
pub updated_by: Pubkey,
pub timestamp: i64,
}Fields
config: Pubkeyminter: Pubkeyis_active: boolmint_quota: u64updated_by: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for MinterUpdatedwhere
Pubkey: BorshDeserialize,
bool: BorshDeserialize,
u64: BorshDeserialize,
i64: BorshDeserialize,
impl BorshDeserialize for MinterUpdatedwhere
Pubkey: BorshDeserialize,
bool: BorshDeserialize,
u64: BorshDeserialize,
i64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MinterUpdated
impl BorshSerialize for MinterUpdated
Sourceimpl Discriminator for MinterUpdated
impl Discriminator for MinterUpdated
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more