pub struct ProgramUnpaused {
pub config: Pubkey,
pub pauser: Pubkey,
pub timestamp: i64,
}Fields
config: Pubkeypauser: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for ProgramUnpaused
impl BorshDeserialize for ProgramUnpaused
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ProgramUnpaused
impl BorshSerialize for ProgramUnpaused
Sourceimpl Discriminator for ProgramUnpaused
impl Discriminator for ProgramUnpaused
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more