pub struct RoleUpdated {
pub config: Pubkey,
pub role: String,
pub old_holder: Pubkey,
pub new_holder: Pubkey,
pub updated_by: Pubkey,
pub timestamp: i64,
}Fields
config: Pubkeyrole: Stringold_holder: Pubkeynew_holder: Pubkeyupdated_by: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for RoleUpdated
impl BorshDeserialize for RoleUpdated
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RoleUpdated
impl BorshSerialize for RoleUpdated
Sourceimpl Discriminator for RoleUpdated
impl Discriminator for RoleUpdated
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more