pub struct StablecoinInitialized {
pub config: Pubkey,
pub mint: Pubkey,
pub master_authority: Pubkey,
pub name: String,
pub symbol: String,
pub preset: u8,
pub timestamp: i64,
}Fields
config: Pubkeymint: Pubkeyname: Stringsymbol: Stringpreset: u8timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for StablecoinInitializedwhere
Pubkey: BorshDeserialize,
String: BorshDeserialize,
u8: BorshDeserialize,
i64: BorshDeserialize,
impl BorshDeserialize for StablecoinInitializedwhere
Pubkey: BorshDeserialize,
String: BorshDeserialize,
u8: BorshDeserialize,
i64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for StablecoinInitialized
impl Discriminator for StablecoinInitialized
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more