pub struct SupplyCapUpdated {
pub config: Pubkey,
pub old_cap: u64,
pub new_cap: u64,
pub timestamp: i64,
}Fields
config: Pubkeyold_cap: u64new_cap: u64timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for SupplyCapUpdated
impl BorshDeserialize for SupplyCapUpdated
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SupplyCapUpdated
impl BorshSerialize for SupplyCapUpdated
Sourceimpl Discriminator for SupplyCapUpdated
impl Discriminator for SupplyCapUpdated
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more