pub struct TokensBurned {
pub config: Pubkey,
pub burner: Pubkey,
pub from: Pubkey,
pub amount: u64,
pub total_burned: u64,
pub timestamp: i64,
}Fields
config: Pubkeyburner: Pubkeyfrom: Pubkeyamount: u64total_burned: u64timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for TokensBurned
impl BorshDeserialize for TokensBurned
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TokensBurned
impl BorshSerialize for TokensBurned
Sourceimpl Discriminator for TokensBurned
impl Discriminator for TokensBurned
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more