pub struct TokensMinted {
pub config: Pubkey,
pub minter: Pubkey,
pub recipient: Pubkey,
pub amount: u64,
pub total_minted: u64,
pub timestamp: i64,
}Fields
config: Pubkeyminter: Pubkeyrecipient: Pubkeyamount: u64total_minted: u64timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for TokensMinted
impl BorshDeserialize for TokensMinted
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TokensMinted
impl BorshSerialize for TokensMinted
Sourceimpl Discriminator for TokensMinted
impl Discriminator for TokensMinted
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more