pub struct AllowlistAdd {
pub params: AllowlistAddParams,
}Expand description
Instruction.
Fields
params: AllowlistAddParamsTrait Implementations
Sourceimpl BorshDeserialize for AllowlistAddwhere
AllowlistAddParams: BorshDeserialize,
impl BorshDeserialize for AllowlistAddwhere
AllowlistAddParams: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AllowlistAddwhere
AllowlistAddParams: BorshSerialize,
impl BorshSerialize for AllowlistAddwhere
AllowlistAddParams: BorshSerialize,
Sourceimpl Discriminator for AllowlistAdd
impl Discriminator for AllowlistAdd
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for AllowlistAdd
impl InstructionData for AllowlistAdd