pub struct UpdateMinter {
pub params: UpdateMinterParams,
}Expand description
Instruction.
Fields
params: UpdateMinterParamsTrait Implementations
Sourceimpl BorshDeserialize for UpdateMinterwhere
UpdateMinterParams: BorshDeserialize,
impl BorshDeserialize for UpdateMinterwhere
UpdateMinterParams: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateMinterwhere
UpdateMinterParams: BorshSerialize,
impl BorshSerialize for UpdateMinterwhere
UpdateMinterParams: BorshSerialize,
Sourceimpl Discriminator for UpdateMinter
impl Discriminator for UpdateMinter
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateMinter
impl InstructionData for UpdateMinter