pub struct UpdateRoles {
pub params: UpdateRoleParams,
}Expand description
Instruction.
Fields
params: UpdateRoleParamsTrait Implementations
Sourceimpl BorshDeserialize for UpdateRoleswhere
UpdateRoleParams: BorshDeserialize,
impl BorshDeserialize for UpdateRoleswhere
UpdateRoleParams: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateRoleswhere
UpdateRoleParams: BorshSerialize,
impl BorshSerialize for UpdateRoleswhere
UpdateRoleParams: BorshSerialize,
Sourceimpl Discriminator for UpdateRoles
impl Discriminator for UpdateRoles
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateRoles
impl InstructionData for UpdateRoles