pub struct InitializeParams {
pub name: String,
pub symbol: String,
pub uri: String,
pub decimals: u8,
pub preset: StablecoinPreset,
pub enable_permanent_delegate: Option<bool>,
pub enable_transfer_hook: Option<bool>,
pub enable_default_state_frozen: Option<bool>,
pub enable_confidential_transfers: Option<bool>,
}Fields
name: Stringsymbol: Stringuri: Stringdecimals: u8preset: StablecoinPresetenable_permanent_delegate: Option<bool>enable_transfer_hook: Option<bool>enable_default_state_frozen: Option<bool>enable_confidential_transfers: Option<bool>Trait Implementations
Sourceimpl BorshDeserialize for InitializeParams
impl BorshDeserialize for InitializeParams
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for InitializeParamswhere
String: BorshSerialize,
u8: BorshSerialize,
StablecoinPreset: BorshSerialize,
Option<bool>: BorshSerialize,
impl BorshSerialize for InitializeParamswhere
String: BorshSerialize,
u8: BorshSerialize,
StablecoinPreset: BorshSerialize,
Option<bool>: BorshSerialize,