pub struct UpdateMetadataParams {
pub name: Option<String>,
pub symbol: Option<String>,
pub uri: Option<String>,
}Fields
name: Option<String>symbol: Option<String>uri: Option<String>Trait Implementations
Sourceimpl BorshDeserialize for UpdateMetadataParams
impl BorshDeserialize for UpdateMetadataParams
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,